@@ -287,6 +287,7 @@ id(NULL),
 console(NULL),
 controls(NULL),
 user_agent(NULL),
+page_url(NULL),
 player_backend(NULL),
 disable_context_menu(FALSE),
 disable_fullscreen(FALSE),
@@ -300,8 +301,28 @@ tv_driver(NULL), tv_device(NULL), tv_input(NULL), tv_width(0), tv_height(0)
 {
     GRand *rand;
     GmPrefStore *store;
+    gboolean b;
 
     NPN_GetValue(mInstance, NPNVWindowNPObject, &sWindowObj);
+    
+    // get the page plugin was called from 
+    // found at https://developer.mozilla.org/en/Getting_the_page_URL_in_NPAPI_plugin
+    NPIdentifier identifier = NPN_GetStringIdentifier( "location" );
+    // Declare a local variant value.
+    NPVariant variantValue;
+    // Get the location property from the window object (which is another object).
+    b = NPN_GetProperty( mInstance, sWindowObj, identifier, &variantValue );
+    // Get a pointer to the "location" object.
+    NPObject *locationObj = variantValue.value.objectValue;
+    // Create a "href" identifier.
+    identifier = NPN_GetStringIdentifier( "href" );
+    // Get the location property from the location object.
+    b = NPN_GetProperty( mInstance, locationObj, identifier, &variantValue );
+#ifdef HAVE_NEW_XULRUNNER
+    page_url = g_strdup_printf("%s",NPVARIANT_TO_STRING(variantValue).UTF8Characters);
+#else
+    page_url = g_strdup_printf("%s",NPVARIANT_TO_STRING(variantValue).utf8characters);
+#endif    
 
     // register methods
     Play_id = NPN_GetStringIdentifier("Play");
@@ -378,6 +399,7 @@ tv_driver(NULL), tv_device(NULL), tv_input(NULL), tv_width(0), tv_height(0)
     bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
     textdomain(GETTEXT_PACKAGE);
 #endif
+   printf(_("gecko mediaplayer v%s\n"), VERSION);
 
     g_type_init();
     store = gm_pref_store_new("gecko-mediaplayer");
@@ -556,9 +578,12 @@ NPError CPlugin::SetWindow(NPWindow * aWindow)
 
     if (playlist != NULL) {
         item = (ListItem *) playlist->data;
+        if (!item->play)
+            item = list_find_next_playable(playlist);
         if (!item->requested) {
             item->cancelled = FALSE;
             if (item->streaming) {
+                printf("Calling open_location with item = %p src = %s\n", item, item->src);
                 open_location(this, item, FALSE);
                 item->requested = 1;
             } else {
@@ -660,7 +685,8 @@ NPError CPlugin::DestroyStream(NPStream * stream, NPError reason)
             path = g_strdup(item->path);
             ready = item->playerready;
             newwindow = item->newwindow;
-            item->streaming = streaming(item->src);
+            if (!item->streaming)
+                item->streaming = streaming(item->src);
             if (!item->streaming) {
                 printf("in Destroy Stream\n");
                 playlist = list_parse_qt(playlist, item);
@@ -828,7 +854,8 @@ int32 CPlugin::WriteReady(NPStream * stream)
             g_strlcpy(item->src, stream->url, 1024);
             item->requested = TRUE;
             item->play = TRUE;
-            item->streaming = streaming(item->src);
+            if (!item->streaming)
+                item->streaming = streaming(item->src);
             playlist = g_list_append(playlist, item);
             stream->notifyData = item;
         } else {
@@ -921,14 +948,17 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
         return -1;
     }
 
-    if (strstr((char *) buffer, "ICY 200 OK") != NULL || strstr((char *) buffer, "Content-length:") != NULL     // If item is a block of jpeg images, just stream it
-        || strstr((char *) buffer, "<HTML>") != NULL || item->streaming == TRUE) {
+    if (strstr((char *) buffer, "ICY 200 OK") != NULL 
+        || strstr((char *) buffer, "Content-length:") != NULL     // If item is a block of jpeg images, just stream it
+        || strstr((char *) buffer, "<HTML>") != NULL 
+        || item->streaming == TRUE ) {
         //   || stream->lastmodified == 0) {    this is not valid for many sites
 
         // printf("BUFFER='%s'\n", buffer);
 
         // printf("item->streaming = %i\n", item->streaming);
         // printf("stream->lastmodified = %i\n", stream->lastmodified);
+        // printf("stream->end = %i\n", stream->end);
 
         item->streaming = TRUE;
         open_location(this, item, FALSE);
@@ -1029,7 +1059,8 @@ int32 CPlugin::Write(NPStream * stream, int32 offset, int32 len, void *buffer)
             path = g_strdup(item->path);
             ready = item->playerready;
             newwindow = item->newwindow;
-            item->streaming = streaming(item->src);
+            if (!item->streaming)
+                item->streaming = streaming(item->src);
             if (!item->streaming) {
                 printf("in Write\n");
                 playlist = list_parse_qt(playlist, item);
@@ -1711,7 +1742,11 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
 
     if (name == PlayAt_id) {
         pPlugin->Play();
-        pPlugin->Seek(NPVARIANT_TO_DOUBLE(args[0]));
+        if ((int)NPVARIANT_TO_DOUBLE(args[0]) == 0 && NPVARIANT_TO_INT32(args[0]) > 0) {
+            pPlugin->Seek((double)NPVARIANT_TO_INT32(args[0]));
+        } else {
+            pPlugin->Seek(NPVARIANT_TO_DOUBLE(args[0]));
+        }
         return PR_TRUE;
     }
 
@@ -1741,7 +1776,12 @@ bool ScriptablePluginObject::Invoke(NPIdentifier name, const NPVariant * args,
     }
 
     if (name == Seek_id) {
-        pPlugin->Seek(NPVARIANT_TO_DOUBLE(args[0]));
+        
+        if ((int)NPVARIANT_TO_DOUBLE(args[0]) == 0 && NPVARIANT_TO_INT32(args[0]) > 0) {
+            pPlugin->Seek((double)NPVARIANT_TO_INT32(args[0]));
+        } else {
+            pPlugin->Seek(NPVARIANT_TO_DOUBLE(args[0]));
+        }
         return PR_TRUE;
     }
 
