@@ -168,7 +168,7 @@ ListItem *list_find_next_playable(GList * list)
         item = (ListItem *) iter->data;
         if (item != NULL) {
             if (item->played == FALSE && item->play == TRUE) {
-                //printf("next playable is %s\n",item->src);
+                // printf("next playable is %s\n",item->src);
                 return item;
             }
         }
@@ -176,6 +176,32 @@ ListItem *list_find_next_playable(GList * list)
     return NULL;
 }
 
+void list_qualify_url(GList * list, gchar *page_url)
+{
+    ListItem *item;
+    GList *iter;
+    gchar *tmp;
+    gchar url[4096];
+    
+    for (iter = list; iter != NULL; iter = g_list_next(iter)) {
+        item = (ListItem *) iter->data;
+        if (item != NULL && item->streaming) {
+            tmp = g_strrstr(item->src, "://");
+            if (!tmp) {
+                if (page_url != NULL) {
+                    //printf("page_url = %s\n", instance->page_url);
+                    g_strlcpy(url, item->src, 4096);
+                    g_strlcpy(item->src, page_url, 1024);
+                    tmp = g_strrstr(item->src, "/");
+                    tmp[1] = '\0';
+                    //printf("item->src = %s\n", item->src);
+                    g_strlcat(item->src, url, 4096);
+                }
+           }
+        }
+    }
+}
+
 GList *list_clear(GList * list)
 {
     ListItem *item;
@@ -215,6 +241,7 @@ void list_dump(GList * list)
                 printf("id = %i\n", item->id);
                 printf("hrefid = %i\n", item->hrefid);
                 printf("play = %i\n", item->play);
+                printf("played = %i\n", item->played);
                 printf("path = %s\n", item->path);
                 printf("controlid = %i\n", item->controlid);
                 printf("playerready = %i\n", item->playerready);
@@ -603,6 +630,7 @@ asx_start_element(GMarkupParseContext * context,
         }
     }
     if (g_ascii_strcasecmp(element_name, "ENTRY") == 0) {
+        parser_item->play = 0;
         entry_id = entry_id + 100;
     }
 }
@@ -713,7 +741,7 @@ GList *list_parse_ram(GList * list, ListItem * item)
     if (item->localsize < (16 * 1024)) {
         if (g_file_get_contents(item->local, &data, &datalen, NULL)) {
             if (data != NULL) {
-                output = g_strsplit(data, "\n", 0);
+                output = g_strsplit_set(data, "\n\r", 0);
                 parser_list = list;
                 parser_item = item;
                 i = 0;
@@ -755,7 +783,7 @@ GList *list_parse_ram(GList * list, ListItem * item)
                                 newitem->src[3] = g_ascii_tolower(newitem->src[3]);
                             }
                             newitem->play = TRUE;
-                            newitem->id = entry_id;
+                            newitem->id = ++entry_id;
                             newitem->controlid = parser_item->controlid;
                             g_strlcpy(newitem->path, parser_item->path, 1024);
                             parser_list = g_list_append(parser_list, newitem);
